from flask import Flask, request, jsonify
from flask_cors import CORS
import requests, re, json, os, yaml
from db import *
from aliexpress import *

app = Flask(__name__)
CORS(app)

def get_conf():
    '''return settings in settings.yaml file'''
    settings = dict()
    with open(os.path.dirname(os.path.realpath(__file__))+"/settings.yaml", 'r') as conf_file:
        settings = yaml.safe_load(conf_file)
    settings["db"] = {
            "host": os.environ.get('POSTGRES_HOST'),
            "port": os.environ.get('POSTGRES_PORT'),
            "database": os.environ.get('POSTGRES_DB'),
            "user": os.environ.get('POSTGRES_USER'),
            "password": os.environ.get('POSTGRES_PASSWORD')
            }

    return settings

@app.route('/init')
def init_db():
    print("init")
    settings = get_conf()
    initialize(settings["db"])
    return 'Hello, World!'

@app.route('/update')
def update_hist():
    print("update")
    settings = get_conf()
    fill_db(settings["db"], check_items(settings["item"]))
    return 'Hello, World!'

@app.route('/add', methods=['POST'])
def add_item():
    print("adding item")

    data = request.get_json()

    itemid = data.get('itemid')
    attributes = data.get('attributes', '').split(',') if data.get('attributes') else []

    new_item = [(itemid, attributes)]
    extr = check_items(new_item)

    if len(extr) > 0:
        settings = get_conf()
        skuid = list(extr.values())[0]["skuid"]
        if check_exist(settings["db"], itemid, skuid):
            # item already exists
            return jsonify({'status': 3}), 400
        else:
            # item is valid
            fill_db(settings["db"], extr)
            return jsonify({'status': 0}), 200
    else:
        # item not valid or can't be parsed
        return jsonify({'status': 1}), 400

@app.route('/datahistory',methods = ['POST', 'GET'])
def data_history_request():
    if request.method == 'GET':
        print("fetching data history")
        settings = get_conf()
        return jsonify(get_history(settings["db"]))

@app.route('/dataitem',methods = ['POST', 'GET'])
def data_item_request():
    if request.method == 'GET':
        print("fetching data item")
        settings = get_conf()
        return jsonify(get_item(settings["db"]))

if __name__ == '__main__':
   app.run(debug = True)
